@@ -1,5 +1,5 @@
 # all the keys in the results dictionary
-results_keys_set = ['system', 'uuid', 'comp_type', 'cluster', 'xc functional', 'exit_status', 'is_finished', 'is_finished_ok', 'E/eV', 'remove_remote_folder',  'previous_calc']
+results_keys_set = ['system', 'uuid', 'comp_type', 'cluster', 'xc functional', 'exit_status', 'is_finished', 'is_finished_ok', 'E/eV', 'remove_remote_folder',  'previous_calc', 'son_calc']
 
 # dictionary for the slurm system on different clusters
 slurm_options = {}
