@@ -162,6 +162,7 @@ def qePwOriginalSubmit(results, codename, structure, kpoints, pseudo_family, met
     results_tmp[str(calc.pk)]['is_finished'] = None
     results_tmp[str(calc.pk)]['is_finished_ok'] = None
     results_tmp[str(calc.pk)]['previous_calc'] = 0 # 0 represent original
+    results_tmp[str(calc.pk)]['son_calc'] = None # currently no son_calc node
     # results_tmp[str(calc.pk)]['description'] = metadata['description']
 
     return results_tmp, calc.pk
@@ -311,5 +312,9 @@ def qePwContinueSubmit(results, pk, codename='', add_parameters={}, del_paramete
     results_tmp[str(calc.pk)]['is_finished'] = None
     results_tmp[str(calc.pk)]['is_finished_ok'] = None
     results_tmp[str(calc.pk)]['previous_calc'] = str(pk) # pk is the previous calculation
+    results_tmp[str(calc.pk)]['son_calc'] = None # right now there is no son_node
+
+    # change son_calc with previous simulation
+    results_tmp[str(pk)]['son_calc'] = str(calc.pk)
 
     return results_tmp, calc.pk
